<div align="center">
  <a href="https://github.com/webpack/webpack">
    <img width="200" height="200"
      src="https://webpack.js.org/assets/icon-square-big.svg">
  </a>
  <h1>Flush CSS Chunks Webpack Plugin</h1>
  <p>Generates CSS hash for mapping between Webpack chunks and CSS chunks.</p>
</div>

 # Installation
 
```bash
yarn add flush-css-chunks-webpack-plugin
```
or
```bash
npm install flush-css-chunks-webpack-plugin
```

## Introduction

 If your using awesome [babel-plugin-dual-import](https://github.com/faceyspacey/babel-plugin-dual-import)
 or [babel-plugin-universal-import](https://github.com/faceyspacey/babel-plugin-universal-import)
 and for some reason you cannot implement SSR than this plugin is what you need.
 
 It maps trough webpack stats and generates ```cssHash```:
 
 ```javascript
window.__CSS_CHUNKS__ = {
    Foo: '/static/Foo.css',
    Bar: '/static/Bar.css'
}
```
```cssHash``` will be injected in your ```.js``` or ```hot-update.js``` files 
which are generated by webpack so that means it also works with Hot module replacement (HMR) :thumbsup:

 # Usage
 
```javascript
const FlushCSSChunksWebpackPlugin = require('flush-css-chunks-webpack-plugin');

const config = {
    entry: '...',
    output: {},
    modules: {},
    plugins: [
        new FlushCSSChunksWebpackPlugin({
            entryOnly: true // defaults to false
        })
    ]
};
```

- **entryOnly** - ***default: false*** By default plugin injects the ```cssHash``` to every ```.js``` 
file produced by webpack as this enables hot swap mapping, if set to ```true``` plugin will only inject the mapping
in the initial ```.js``` bundle (use only for **PRODUCTION**)

